@@ -1879,6 +1879,7 @@ ephy_web_view_load_error_page (EphyWebView         *view,
                    page == EPHY_WEB_VIEW_ERROR_INVALID_TLS_CERTIFICATE ? "danger" : "default",
                    msg_title, msg_body,
                    msg_details ? "visible" : "hidden",
+                   _("Technical information"),
                    msg_details,
                    hidden_button_label ? "visible" : "hidden",
                    hidden_button_accesskey, hidden_button_label,
@@ -1915,16 +1916,13 @@ load_failed_cb (WebKitWebView  *web_view,
   view->load_failed = TRUE;
   ephy_web_view_set_link_message (view, NULL);
 
-  if (error->domain == SOUP_HTTP_ERROR ||
-      error->domain == G_TLS_ERROR) {
+  if (error->domain != WEBKIT_NETWORK_ERROR &&
+      error->domain != WEBKIT_POLICY_ERROR &&
+      error->domain != WEBKIT_PLUGIN_ERROR) {
     ephy_web_view_load_error_page (view, uri, EPHY_WEB_VIEW_ERROR_PAGE_NETWORK_ERROR, error);
     return TRUE;
   }
 
-  g_return_val_if_fail ((error->domain == WEBKIT_NETWORK_ERROR) ||
-                        (error->domain == WEBKIT_POLICY_ERROR) ||
-                        (error->domain == WEBKIT_PLUGIN_ERROR), FALSE);
-
   switch (error->code) {
     case WEBKIT_NETWORK_ERROR_FAILED:
     case WEBKIT_NETWORK_ERROR_TRANSPORT:
@@ -2152,8 +2150,11 @@ ephy_web_view_new (void)
 GtkWidget *
 ephy_web_view_new_with_related_view (WebKitWebView *related_view)
 {
+  EphyEmbedShell *shell = ephy_embed_shell_get_default ();
+
   return g_object_new (EPHY_TYPE_WEB_VIEW,
                        "related-view", related_view,
+                       "user-content-manager", ephy_embed_shell_get_user_content_manager (shell),
                        "settings", ephy_embed_prefs_get_settings (),
                        NULL);
 }
